@@ -15,7 +15,7 @@
 # You should have received a copy of the GNU Lesser General Public License
 # along with FIAT. If not, see <http://www.gnu.org/licenses/>.
 
-import finite_element, polynomial_set, dual_set , functional
+from . import finite_element, polynomial_set, dual_set , functional
 
 class LagrangeDualSet( dual_set.DualSet ):
     """The dual basis for Lagrange elements.  This class works for
@@ -38,7 +38,7 @@ class LagrangeDualSet( dual_set.DualSet ):
                               for x in pts_cur ]
                 nnodes_cur = len( nodes_cur )
                 nodes +=  nodes_cur
-                entity_ids[dim][entity] = range(cur,cur+nnodes_cur)
+                entity_ids[dim][entity] = list(range(cur,cur+nnodes_cur))
                 cur += nnodes_cur
 
         dual_set.DualSet.__init__( self , nodes , ref_el , entity_ids )
@@ -51,7 +51,7 @@ class Lagrange( finite_element.FiniteElement ):
         finite_element.FiniteElement.__init__( self , poly_set , dual , degree )
 
 if __name__=="__main__":
-    import reference_element
+    from . import reference_element
     # UFC triangle and points
     T = reference_element.UFCTriangle()
     pts = T.make_lattice(1)
@@ -63,8 +63,8 @@ if __name__=="__main__":
 
     L = Lagrange(T, 1)
     Ufs = L.get_nodal_basis()
-    print pts
-    for foo,bar in Ufs.tabulate( pts ,1 ).iteritems():
-        print foo
-        print bar
-        print
+    print(pts)
+    for foo,bar in Ufs.tabulate( pts ,1 ).items():
+        print(foo)
+        print(bar)
+        print()
