@@ -1,5 +1,22 @@
-import lagrange
-import reference_element
+# Copyright (C) 2008-2012 Robert C. Kirby (Texas Tech University)
+#
+# This file is part of FIAT.
+#
+# FIAT is free software: you can redistribute it and/or modify
+# it under the terms of the GNU Lesser General Public License as published by
+# the Free Software Foundation, either version 3 of the License, or
+# (at your option) any later version.
+#
+# FIAT is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+# GNU Lesser General Public License for more details.
+#
+# You should have received a copy of the GNU Lesser General Public License
+# along with FIAT. If not, see <http://www.gnu.org/licenses/>.
+
+from . import lagrange
+from . import reference_element
 import string
 import numpy
 
@@ -32,12 +49,12 @@ for i in range(3,4):
     nb = L.get_nodal_basis()
     vdm = nb.get_coeffs()
     array_name="Lagrange%s%dCoeffs"%(shape,i)
-    print matrix_to_array( vdm , array_name )
-    print lagclass % (shape,i,shape,i,\
+    print(matrix_to_array( vdm , array_name ))
+    print(lagclass % (shape,i,shape,i,\
                           nb.get_degree(), \
                           nb.get_embedded_degree(), \
                           2,\
                           nb.get_num_members() , \
                           nb.get_num_members() , \
-                          array_name,shape,i)
-    
+                          array_name,shape,i))
+
