@@ -1,3 +1,20 @@
+# Copyright (C) 2008-2012 Robert C. Kirby (Texas Tech University)
+#
+# This file is part of FIAT.
+#
+# FIAT is free software: you can redistribute it and/or modify
+# it under the terms of the GNU Lesser General Public License as published by
+# the Free Software Foundation, either version 3 of the License, or
+# (at your option) any later version.
+#
+# FIAT is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+# GNU Lesser General Public License for more details.
+#
+# You should have received a copy of the GNU Lesser General Public License
+# along with FIAT. If not, see <http://www.gnu.org/licenses/>.
+
 # polynomial sets
 # basic interface:
 # -- defined over some reference element
@@ -9,9 +26,9 @@
 # we have an interface for defining sets of functionals (moments against
 # an entire set of polynomials)
 
-import expansions
+from . import expansions
 import numpy
-from functional import index_iterator
+from .functional import index_iterator
 import Scientific.Functions.FirstDerivatives as FirstDerivatives
 
 def mis( m , n ):
@@ -226,19 +243,19 @@ def polynomial_set_union_normalized( A , B ):
                           coeffs , A.get_dmats() )
 
 if __name__ == "__main__":
-    import reference_element
+    from . import reference_element
 
     T = reference_element.UFCTriangle()
     U = ONPolynomialSet( T , 2 )
 
-    print U.coeffs[0:6,0:6]
+    print(U.coeffs[0:6,0:6])
 
     pts = T.make_lattice( 3 )
 
     jet = U.tabulate( pts , 1 )
     for alpha in sorted( jet ):
-        print alpha
-        print jet[alpha]
+        print(alpha)
+        print(jet[alpha])
 
 
 #    print U.get_shape()
