@@ -16,7 +16,7 @@
 # along with FIAT. If not, see <http://www.gnu.org/licenses/>.
 #
 # First added:  2010-01-31
-# Last changed: 2010-01-31
+# Last changed: 2012-10-01
 
 import sys, pickle
 from FIAT import supported_elements, make_quadrature, ufc_simplex
@@ -41,6 +41,7 @@ test_cases = (("Lagrange", 2, 1),
               ("Brezzi-Douglas-Marini", 3, 1),
               ("Brezzi-Douglas-Marini", 3, 2),
               ("Brezzi-Douglas-Marini", 3, 3),
+              ("Brezzi-Douglas-Fortin-Marini", 2, 2),
               ("Raviart-Thomas", 2, 1),
               ("Raviart-Thomas", 2, 2),
               ("Raviart-Thomas", 2, 3),
@@ -57,6 +58,8 @@ test_cases = (("Lagrange", 2, 1),
               ("Nedelec 2nd kind H(curl)", 2, 2),
               ("Nedelec 2nd kind H(curl)", 2, 3),
               ("Nedelec 2nd kind H(curl)", 3, 1),
+              ("Nedelec 2nd kind H(curl)", 3, 2),
+              ("Nedelec 2nd kind H(curl)", 3, 3),
               ("Crouzeix-Raviart", 2, 1),
               ("Crouzeix-Raviart", 3, 1))
 
@@ -78,7 +81,7 @@ def test():
     values = {}
     for test_case in test_cases:
 
-        print "Testing", test_case
+        print("Testing", test_case)
 
         # Get family, dimension and degree
         family, dim, degree = test_case
@@ -103,24 +106,24 @@ def test():
             reference_table = reference[(family, dim, degree)]
             for dtuple in reference_table:
                 if dtuple not in table:
-                    print "*** Missing dtuple in table for " + str(test_case)
+                    print("*** Missing dtuple in table for " + str(test_case))
                     return 1
                 elif shape(table[dtuple]) != shape(reference_table[dtuple]):
-                    print "*** Wrong shape in table for " + str(test_case)
+                    print("*** Wrong shape in table for " + str(test_case))
                     return 1
                 else:
                     diff = max(abs(table[dtuple] - reference_table[dtuple]))
                     if diff > tolerance:
-                        print "*** Wrong values in table for %s, difference is %g" % (str(test_case), diff)
+                        print("*** Wrong values in table for %s, difference is %g" % (str(test_case), diff))
                         return 1
 
     # Write new values if reference is missing
     if reference is None:
-        print "Storing new reference values"
+        print("Storing new reference values")
         pickle.dump(values, open("reference.pickle", "w"))
 
-    print
-    print "Ran %d tests: OK" % len(test_cases)
+    print()
+    print("Ran %d tests: OK" % len(test_cases))
 
     return 0
 
